@@ -11,7 +11,7 @@ pub fn load(file_path: &str) -> Result<DotjectorConfig, ()> {
 #[derive(Serialize, Deserialize, Debug)]
 pub struct DotjectorConfig {
     pub templates: HashMap<String, Template>,
-    pub contexts: HashMap<String, FileSource>,
+    pub contexts: HashMap<String, Context>,
 }
 
 #[derive(Serialize, Deserialize, Debug)]
@@ -21,6 +21,19 @@ pub struct Template {
     pub requires: Option<Vec<String>>,
 }
 
+#[derive(Serialize, Deserialize, Debug)]
+pub struct Context {
+    pub input: FileSource,
+    pub encoding: ContextEncoding,
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone, Hash)]
+#[allow(non_camel_case_types)]
+pub enum ContextEncoding {
+    plain,
+    yaml,
+}
+
 #[derive(Serialize, Deserialize, Debug, Clone, Hash)]
 #[allow(non_camel_case_types)]
 pub enum FileSource {
@@ -30,4 +43,11 @@ pub enum FileSource {
         r#ref: String,
         file: String,
     },
+    http(String),
+}
+
+impl std::fmt::Display for Template {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "Template({:?} -> {})", self.input, self.output)
+    }
 }
