@@ -1,5 +1,7 @@
 use thiserror::Error;
 
+use crate::config::ContextEncoding;
+
 pub type Result<T> = std::result::Result<T, Error>;
 
 #[derive(Error, Debug)]
@@ -12,4 +14,6 @@ pub enum Error {
     InputSourceNotFound(String),
     #[error("{0}")]
     FetchError(crate::fetch::Error),
+    #[error("Could not parse input \"{1}\" as \"{0:?}\": {2}")]
+    InputSourceDecodingError(ContextEncoding, String, String),
 }
