@@ -1,6 +1,6 @@
 use std::{fs::File, io::Write, sync::Arc};
 
-use log::{debug, info};
+use log::{info, warn};
 use thiserror::Error;
 
 use tera::Context;
@@ -40,10 +40,7 @@ pub async fn process(
     };
 
     output_file.write(output.as_bytes()).unwrap();
-    debug!(
-        "Processed template {:?} and wrote output to {}",
-        &template_config, &template_config.output
-    );
+    warn!("Processed {}", &template_config);
 
     Ok(())
 }
